@@ -54,9 +54,10 @@ extern struct timeval time;
 
 #define AFS_PROC        struct proc
 
-#define osi_vnhold(avc,r)  do { \
-       if ((avc)->vrefCount) { VN_HOLD(&((avc)->v)); } \
-       else (avc)->vrefCount = 1;  } while(0)
+#define osi_vnhold(avc,r)       VN_HOLD(AFSTOV(avc))
+#define VN_HOLD(vp) darwin_vn_hold(vp)
+#define VN_RELE(vp) vrele(vp);
+
 
 #define gop_rdwr(rw,gp,base,len,offset,segflg,unit,cred,aresid) \
   vn_rdwr((rw),(gp),(base),(len),(offset),(segflg),(unit),(cred),(aresid),current_proc())
@@ -84,9 +85,6 @@ extern struct lock__bsd__ afs_global_lock;
         lockmgr(&afs_global_lock, LK_RELEASE, 0, current_proc()); \
     } while(0)
 #define ISAFS_GLOCK() (afs_global_owner == current_thread())
-#define AFS_RXGLOCK()
-#define AFS_RXGUNLOCK()
-#define ISAFS_RXGLOCK() 1
 
 #define SPLVAR
 #define NETPRI
@@ -106,6 +104,11 @@ extern struct lock__bsd__ afs_global_lock;
 extern ino_t VnodeToIno(vnode_t * vp);
 extern dev_t VnodeToDev(vnode_t * vp);
 
+#define osi_curproc() current_proc()
+
+/* FIXME */
+#define osi_curcred() &afs_osi_cred 
+
 #endif /* KERNEL */
 
 #endif /* _OSI_MACHDEP_H_ */
